==> fnschool-20240412.2240.38.tar.gz: fnschool-20240412.2240.38/README.md <==

<h1 align="center">
  <br>
  
  <pre> _____ _   _ ____   ____ _   _  ___   ___  _     
|  ___| \ | / ___| / ___| | | |/ _ \ / _ \| |    
| |_  |  \| \___ \| |   | |_| | | | | | | | |    
|  _| | |\  |___) | |___|  _  | |_| | |_| | |___ 
|_|   |_| \_|____/ \____|_| |_|\___/ \___/|_____|
                                                 
</pre>

  <br>
  funingschool
  <br>
</h1>

<h4 align="center"> Some simple scripts for warehousing and consuming. </h4>

<p align="center">
  <a href="https://github.com/larryw3i/funingschool/blob/master/Documentation/README.zh_CN.md">简体中文</a> •
  <a href="https://github.com/larryw3i/funingschool/blob/master/README.md">English</a>
</p>

<p align="center">
  <a href="#key-features">Key Features</a> •
  <a href="#how-to-use">How To Use</a> •
  <a href="#download">Download</a> •
  <a href="#credits">Credits</a> •
  <a href="#related">Related</a> •
  <a href="#license">License</a>
</p>

![screenshot](https://raw.githubusercontent.com/larryw3i/funingschool/master/Documentation/images/9432e132-f8cd-11ee-8ee6-f37309efa64b.png)

## Key Features

* Read food spreadsheets automatically.  
* The simplest and most straightforward `consuming sheets`.  
* Update sheets (warehousing, consuming, summing, etc) automatically.  
* Reduce calculation errors.  
* Easy to use.  

## How To Use

### Install Python3

Ubuntu: 
```bash
sudo apt-get install -U python3 python3-pip
```
Windows:   
Install Python3 from [www.python.org/getit](https://www.python.org/getit/).  

### Install fnschool and run it
```bash
# install
pip3 install -U fnschool
# run
fnschool-cli canteen mk_bill
```

> **Note**  
> Read the information it prompts carefully, which is the key to using it well.


## Credits

This software uses the following open source packages:

- [colorama](https://github.com/tartley/colorama)  
- [pandas](https://pandas.pydata.org/)  
- [numpy](https://numpy.org/)  
- [openpyxl](https://openpyxl.readthedocs.io/)  
- [appdirs](http://github.com/ActiveState/appdirs)  


## Support
Buy me a `coffee`:  

![Buy me a coffee](https://raw.githubusercontent.com/larryw3i/funingschool/master/Documentation/images/9237879a-f8d5-11ee-8411-23057db0a773.jpeg)

## License

[GNU LESSER GENERAL PUBLIC LICENSE Version 3](https://github.com/larryw3i/funingschool/blob/master/LICENSE)

==> fnschool-20240412.2250.49.tar.gz: fnschool-20240412.2250.49/README.md <==

<h1 align="center">
  <br>
  
  <pre> _____ _   _ ____   ____ _   _  ___   ___  _     
|  ___| \ | / ___| / ___| | | |/ _ \ / _ \| |    
| |_  |  \| \___ \| |   | |_| | | | | | | | |    
|  _| | |\  |___) | |___|  _  | |_| | |_| | |___ 
|_|   |_| \_|____/ \____|_| |_|\___/ \___/|_____|
                                                 
</pre>

  <br>
  funingschool
  <br>
</h1>

<h4 align="center"> Some simple scripts for warehousing and consuming. </h4>

<p align="center">
  <a href="https://github.com/larryw3i/funingschool/blob/master/Documentation/README.zh_CN.md">简体中文</a> •
  <a href="https://github.com/larryw3i/funingschool/blob/master/README.md">English</a>
</p>

<p align="center">
  <a href="#key-features">Key Features</a> •
  <a href="#how-to-use">How To Use</a> •
  <a href="#download">Download</a> •
  <a href="#credits">Credits</a> •
  <a href="#related">Related</a> •
  <a href="#license">License</a>
</p>

![screenshot](https://raw.githubusercontent.com/larryw3i/funingschool/master/Documentation/images/9432e132-f8cd-11ee-8ee6-f37309efa64b.png)

## Key Features

* Read food spreadsheets automatically.  
* The simplest and most straightforward `consuming sheets`.  
* Update sheets (warehousing, consuming, summing, etc) automatically.  
* Reduce calculation errors.  
* Easy to use.  

## How To Use

### Install Python3

Ubuntu: 
```bash
sudo apt-get install python3 python3-pip
```
Windows:   
Install Python3 from [www.python.org/getit](https://www.python.org/getit/).  

### Install fnschool and run it
```bash
# install
pip3 install -U fnschool
# run
fnschool-cli canteen mk_bill
```

> **Note**  
> Read the information it prompts carefully, which is the key to using it well.


## Credits

This software uses the following open source packages:

- [colorama](https://github.com/tartley/colorama)  
- [pandas](https://pandas.pydata.org/)  
- [numpy](https://numpy.org/)  
- [openpyxl](https://openpyxl.readthedocs.io/)  
- [appdirs](http://github.com/ActiveState/appdirs)  


## Support

Buy me a `coffee`:  

![Buy me a coffee](https://raw.githubusercontent.com/larryw3i/funingschool/master/Documentation/images/9237879a-f8d5-11ee-8411-23057db0a773.jpeg)

## License

[GNU LESSER GENERAL PUBLIC LICENSE Version 3](https://github.com/larryw3i/funingschool/blob/master/LICENSE)
